package com.xinelu.manage.service.patientblacklist;

import com.xinelu.manage.domain.patientblacklist.PatientBlacklist;
import com.xinelu.manage.dto.patientblacklist.PatientBlacklistDto;
import com.xinelu.manage.dto.patientblacklist.PatientBlacklistSaveDto;
import com.xinelu.manage.vo.patientblacklist.PatientBlacklistVo;
import java.util.List;

/**
 * 患者-黑明单关系Service接口
 *
 * @author haown
 * @date 2024-02-27
 */
public interface IPatientBlacklistService {
    /**
     * 查询患者-黑明单关系
     *
     * @param id 患者-黑明单关系主键
     * @return 患者-黑明单关系
     */
    public PatientBlacklistVo selectPatientBlacklistById(Long id);

    /**
     * 查询患者-黑明单关系列表
     *
     * @param patientBlacklist 患者-黑明单关系
     * @return 患者-黑明单关系集合
     */
    public List<PatientBlacklistVo> selectPatientBlacklistList(PatientBlacklistDto patientBlacklist);

    /**
     * 新增患者-黑明单关系
     *
     * @param blacklistSaveDto 患者-黑明单关系
     * @return 结果
     */
    public int insertPatientBlacklist(PatientBlacklistSaveDto blacklistSaveDto);

    /**
     * 修改患者-黑明单关系
     *
     * @param patientBlacklist 患者-黑明单关系
     * @return 结果
     */
    public int updatePatientBlacklist(PatientBlacklist patientBlacklist);

    /**
     * 批量删除患者-黑明单关系
     *
     * @param ids 需要删除的患者-黑明单关系主键集合
     * @return 结果
     */
    public int deletePatientBlacklistByIds(Long[] ids);

    /**
     * 删除患者-黑明单关系信息
     *
     * @param id 患者-黑明单关系主键
     * @return 结果
     */
    public int deletePatientBlacklistById(Long id);
}
